summaryrefslogtreecommitdiffstats
path: root/include/net.h
diff options
context:
space:
mode:
authorSascha Hauer <s.hauer@pengutronix.de>2007-07-05 18:02:06 +0200
committerSascha Hauer <sha@octopus.labnet.pengutronix.de>2007-07-05 18:02:06 +0200
commit5ab5b339a22293046c194c2813acb67a25e9baad (patch)
treeb57ace834e444304d28330b8aa4a4dbe99874594 /include/net.h
parent955ed9aae146ecb567d086b1cb5fd696188b92f0 (diff)
downloadbarebox-5ab5b339a22293046c194c2813acb67a25e9baad.tar.gz
barebox-5ab5b339a22293046c194c2813acb67a25e9baad.tar.xz
svn_rev_574
eth_init -> eth_open
Diffstat (limited to 'include/net.h')
-rw-r--r--include/net.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/include/net.h b/include/net.h
index 7bc92ce838..993a2ad7e5 100644
--- a/include/net.h
+++ b/include/net.h
@@ -60,6 +60,7 @@ struct eth_device {
int state;
int (*init) (struct eth_device*);
+
int (*open) (struct eth_device*);
int (*send) (struct eth_device*, void *packet, int length);
int (*recv) (struct eth_device*);
@@ -89,8 +90,8 @@ struct eth_device *eth_get_dev_by_name(char *devname); /* get device */
int eth_get_dev_index (void); /* get the device index */
void eth_set_enetaddr(int num, char* a); /* Set new MAC address */
-int eth_init(void); /* Initialize the device */
-int eth_send(void *packet, int length); /* Send a packet */
+int eth_open(void); /* open the device */
+int eth_send(void *packet, int length); /* Send a packet */
int eth_rx(void); /* Check for received packets */
void eth_halt(void); /* stop SCC */
char *eth_get_name(void); /* get name of current device */